DateEdit
================================

.. currentmodule:: enaml.widgets.date_edit

.. autoclass:: DateEdit


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_date_edit.QtDateEdit
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_date_edit.QtDateEdit

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_date_edit.WXDateEdit
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_date_edit.WXDateEdit
